@@ -1,5 +1,3 @@
-"""PyTorch class for feed foward inference network."""
-
 from collections import OrderedDict
 from torch import nn
 import torch
@@ -10,8 +8,9 @@ class ContextualInferenceNetwork(nn.Module):
     """Inference Network."""
 
     def __init__(self, input_size, bert_size, output_size, hidden_sizes,
-                 activation='softplus', dropout=0.2):
+                 activation='softplus', dropout=0.2, label_size=0):
         """
+        # TODO: check dropout in main caller
         Initialize InferenceNetwork.
 
         Args
@@ -40,8 +39,8 @@ class ContextualInferenceNetwork(nn.Module):
         elif activation == 'relu':
             self.activation = nn.ReLU()
 
-        self.input_layer = nn.Linear(input_size+input_size, hidden_sizes[0])
-        self.adapt_bert = nn.Linear(bert_size, hidden_sizes[0])
+        self.input_layer = nn.Linear(bert_size + label_size, hidden_sizes[0])
+        #self.adapt_bert = nn.Linear(bert_size, hidden_sizes[0])
 
         self.hiddens = nn.Sequential(OrderedDict([
             ('l_{}'.format(i), nn.Sequential(nn.Linear(h_in, h_out), self.activation))
@@ -55,11 +54,16 @@ class ContextualInferenceNetwork(nn.Module):
 
         self.dropout_enc = nn.Dropout(p=self.dropout)
 
-    def forward(self, x, x_bert):
+    def forward(self, x, x_bert, labels=None):
         """Forward pass."""
-        x_bert = self.adapt_bert(x_bert)
 
-        x = self.activation(x_bert)
+        x = x_bert
+        if labels:
+            x = torch.cat((x_bert, labels), 1)
+
+        x = self.input_layer(x)
+
+        x = self.activation(x)
         x = self.hiddens(x)
         x = self.dropout_enc(x)
         mu = self.f_mu_batchnorm(self.f_mu(x))
@@ -68,14 +72,12 @@ class ContextualInferenceNetwork(nn.Module):
         return mu, log_sigma
 
 
-
-
 class CombinedInferenceNetwork(nn.Module):
 
     """Inference Network."""
 
     def __init__(self, input_size, bert_size, output_size, hidden_sizes,
-                 activation='softplus', dropout=0.2):
+                 activation='softplus', dropout=0.2, label_size=0):
         """
         Initialize InferenceNetwork.
 
@@ -105,9 +107,10 @@ class CombinedInferenceNetwork(nn.Module):
         elif activation == 'relu':
             self.activation = nn.ReLU()
 
-        self.input_layer = nn.Linear(input_size+input_size, hidden_sizes[0])
+
         self.adapt_bert = nn.Linear(bert_size, input_size)
-        self.bert_layer = nn.Linear(hidden_sizes[0], hidden_sizes[0])
+        #self.bert_layer = nn.Linear(hidden_sizes[0], hidden_sizes[0])
+        self.input_layer = nn.Linear(input_size + input_size + label_size, hidden_sizes[0])
 
         self.hiddens = nn.Sequential(OrderedDict([
             ('l_{}'.format(i), nn.Sequential(nn.Linear(h_in, h_out), self.activation))
@@ -121,10 +124,15 @@ class CombinedInferenceNetwork(nn.Module):
 
         self.dropout_enc = nn.Dropout(p=self.dropout)
 
-    def forward(self, x, x_bert):
+    def forward(self, x, x_bert, labels=None):
         """Forward pass."""
         x_bert = self.adapt_bert(x_bert)
+
         x = torch.cat((x, x_bert), 1)
+
+        if labels is not None:
+            x = torch.cat((x, labels), 1)
+
         x = self.input_layer(x)
 
         x = self.activation(x)
